<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Mega Tour
 * @since Mega Tour 1.0.0
 * @return array An array of default values
 */

function mega_tour_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$mega_tour_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#F38625',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'mega-tour' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'mega-tour' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'mega-tour' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,about,featured,package,cta,blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'mega-tour' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */


		// Slider
		'slider_section_enable'			=> false,
		'slider_autoplay'				=> false,
		'slider_btn_label'				=> esc_html__( 'View Details', 'mega-tour' ),
		'slider_video_label'			=> esc_html__( 'Watch video', 'mega-tour' ),


		// featured
		'featured_section_enable'		=> false,
		'featured_title'				=>esc_html('Discover By Interest',',ega-tour-pro'),
		'featured_content_type'			=> 'page',
		'featured_count'				=> 4,
		'featured_btn_title'			=> esc_html__( 'Discover By Interests
		', 'mega-tour' ),
		'featured_read_more_btn_title'	=> esc_html__('Explore More', 'mega-tour'),


		// about
		'about_section_enable'			=> false,
		'about_section_counter_enable'	=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'About Us', 'mega-tour' ),
		'about_btn_title'				=> esc_html__( 'Explore More', 'mega-tour' ),

		// package
		'package_section_enable'		=> false,
		'package_content_type'			=> 'page',
		'package_count'					=> 1,
		'package_title'					=> esc_html__( 'Recommended Packages', 'mega-tour' ),
		'package_btn_title'				=> esc_html__( 'Book This Package', 'mega-tour' ),


		// blog
		'blog_section_enable'			=> false,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 3,
		'blog_title'					=> esc_html__( 'Read Our Travel Blog', 'mega-tour' ),
		'blog_btn_title'				=> esc_html__( 'Read All Articles', 'mega-tour' ),

		//cta
		'cta_section_enable' 			=>false,
		'cta_title'						=>esc_html__('Travel is a cure to the mind', 'mega-tour'),
		'cta_read_more'					=>esc_html__('Learn More About It', 'mega-tour'),
		'cta_background_image'			=> esc_url(get_template_directory_uri().'/assets/uploads/call-to-action.jpg' ),

	);

	$output = apply_filters( 'mega_tour_default_theme_options', $mega_tour_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}