<?php
/**
 * Featured Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour
 * @since Mega Tour 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'mega_tour_featured_section', array(
	'title'             => esc_html__( 'Featured','mega-tour' ),
	'description'       => esc_html__( 'Note : Activate WP Travel plugin to enable this section options.', 'mega-tour' ),
	'panel'             => 'mega_tour_front_page_panel',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'mega_tour_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'mega_tour_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Switch_Control( $wp_customize, 'mega_tour_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'mega-tour' ),
	'section'           => 'mega_tour_featured_section',
	'on_off_label' 		=> mega_tour_switch_options(),
) ) );


// featured title setting and control
$wp_customize->add_setting( 'mega_tour_theme_options[featured_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_theme_options[featured_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour' ),
	'section'        	=> 'mega_tour_featured_section',
	'active_callback' 	=> 'mega_tour_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_theme_options[featured_title]', array(
		'selector'            => '#featured-packages .section-header-wrapper .section-header h2.section-title',
		'settings'            => 'mega_tour_theme_options[featured_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_featured_title_partial',
    ) );
}

// Featured content type control and setting
$wp_customize->add_setting( 'mega_tour_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'mega_tour_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour' ),
	'section'           => 'mega_tour_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_is_featured_section_enable',
	'choices'			=> mega_tour_featured_content_type(),
) );

$wp_customize->add_setting(  'mega_tour_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'mega_tour_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Mega_Tour_Dropdown_Category_Control( $wp_customize,'mega_tour_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-tour' ),
	'description'      	=> esc_html__( 'Note: Featured selected no of posts will be shown from selected category', 'mega-tour' ),
	'section'           => 'mega_tour_featured_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_is_featured_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_theme_options[featured_content_trip_types]', array(
	'sanitize_callback' => 'mega_tour_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Mega_Tour_Dropdown_Category_Control( $wp_customize,'mega_tour_theme_options[featured_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'mega-tour' ),
	'section'           => 'mega_tour_featured_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_is_featured_section_content_trip_types_enable'
) ) );