<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Mega Tour
 * @since Mega Tour 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function mega_tour_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-tour' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function mega_tour_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-tour' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function mega_tour_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-tour' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}


if ( ! function_exists( 'mega_tour_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function mega_tour_selected_sidebar() {
        $mega_tour_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'mega-tour' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'mega-tour' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'mega-tour' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'mega-tour' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'mega-tour' ),
        );

        $output = apply_filters( 'mega_tour_selected_sidebar', $mega_tour_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function mega_tour_site_layout() {
        $mega_tour_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'mega_tour_site_layout', $mega_tour_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'mega_tour_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function mega_tour_global_sidebar_position() {
        $mega_tour_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'mega_tour_global_sidebar_position', $mega_tour_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'mega_tour_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function mega_tour_sidebar_position() {
        $mega_tour_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'mega_tour_sidebar_position', $mega_tour_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'mega_tour_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function mega_tour_pagination_options() {
        $mega_tour_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'mega-tour' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'mega-tour' ),
        );

        $output = apply_filters( 'mega_tour_pagination_options', $mega_tour_pagination_options );

        return $output;
    }
endif;


if ( ! function_exists( 'mega_tour_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function mega_tour_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'mega-tour' ),
            'off'       => esc_html__( 'Disable', 'mega-tour' )
        );
        return apply_filters( 'mega_tour_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'mega_tour_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function mega_tour_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'mega-tour' ),
            'off'       => esc_html__( 'No', 'mega-tour' )
        );
        return apply_filters( 'mega_tour_hide_options', $arr );
    }
endif;



if ( ! function_exists( 'mega_tour_slider_content_type' ) ) :
    /**
     * slider Options
     * @return array site slider options
     */
    function mega_tour_slider_content_type() {
        $mega_tour_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-tour' ),
            'post'      => esc_html__( 'Post', 'mega-tour' ),
            'category'  => esc_html__( 'Category', 'mega-tour' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_tour_slider_content_type = array_merge( $mega_tour_slider_content_type, array(
                'trip'          => esc_html__( 'Trip', 'mega-tour' ),
                'trip-types'    => esc_html__( 'Trip Types', 'mega-tour' ),
                'destination'   => esc_html__( 'Destination', 'mega-tour' ),
                'activity'      => esc_html__( 'Activity', 'mega-tour' ),
                ) );
        }

        $output = apply_filters( 'mega_tour_slider_content_type', $mega_tour_slider_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_featured_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function mega_tour_featured_content_type() {
        $mega_tour_featured_content_type = array(
            'category'      => esc_html__( 'Category', 'mega-tour' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_tour_featured_content_type = array_merge( $mega_tour_featured_content_type, array(
                'trip-types'          => esc_html__( 'Trip Types', 'mega-tour' ),
                ) );
        }

        $output = apply_filters( 'mega_tour_featured_content_type', $mega_tour_featured_content_type );


        return $output;
    }
endif;


if ( ! function_exists( 'mega_tour_package_content_type' ) ) :
    /**
     * Package Options
     * @return array site gallery options
     */
    function mega_tour_package_content_type() {
        $mega_tour_package_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-tour' ),

        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_tour_package_content_type = array_merge( $mega_tour_package_content_type, array(
                'trip'    => esc_html__( 'Trip', 'mega-tour' ),    
                ) );
        }

        $output = apply_filters( 'mega_tour_package_content_type', $mega_tour_package_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_cta_content_type' ) ) :
    /**
     * cta Options
     * @return array site cta options
     */
    function mega_tour_cta_content_type() {
        $mega_tour_cta_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-tour' ),
            'post'      => esc_html__( 'Post', 'mega-tour' ),
            'custom'    => esc_html__( 'Custom', 'mega-tour' ),
        );

        $output = apply_filters( 'mega_tour_cta_content_type', $mega_tour_cta_content_type );
        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_blog_content_type' ) ) :
    /**
     * Package Options
     * @return array site blog options
     */
    function mega_tour_blog_content_type() {
        $mega_tour_blog_content_type = array(
            'category'  => esc_html__( 'Category', 'mega-tour' ),
            'recent' 	=> esc_html__( 'Recent', 'mega-tour' ),
        );

        $output = apply_filters( 'mega_tour_blog_content_type', $mega_tour_blog_content_type );

        return $output;
    }
endif;