<?php
/**
 * cta section
 *
 * This is the template for the content of cta section
 *
 * @package Theme Palace
 * @subpackage Mega Tour
 * @since Mega Tour 1.0.0
 */
if ( ! function_exists( 'mega_tour_add_cta_section' ) ) :
    /**
    * Add cta section
    *
    *@since Mega Tour 1.0.0
    */
    function mega_tour_add_cta_section() {
    	$options = mega_tour_get_theme_options();
        // Check if cta is enabled on frontpage
        $cta_enable = apply_filters( 'mega_tour_section_status', true, 'cta_section_enable' );

        if ( true !== $cta_enable ) {
            return false;
        }
        // Get cta section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_filter_cta_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render cta section now.
        mega_tour_render_cta_section( $section_details[0] );
    }
endif;

if ( ! function_exists( 'mega_tour_get_cta_section_details' ) ) :
    /**
    * cta section details.
    *
    * @since Mega Tour 1.0.0
    * @param array $input cta section details.
    */
    function mega_tour_get_cta_section_details( $input ) {
        $options = mega_tour_get_theme_options();

        $content = array();
        $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
        $args = array(
            'post_type'         => 'page',
            'posts_per_page'    => 1,
            'p'                 => $page_id,
            'ignore_sticky_posts'   => true,
            );                    


        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = mega_tour_trim_content( 30 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// cta section content details.
add_filter( 'mega_tour_filter_cta_section_details', 'mega_tour_get_cta_section_details' );


if ( ! function_exists( 'mega_tour_render_cta_section' ) ) :
  /**
   * Start cta section
   *
   * @return string cta content
   * @since Mega Tour 1.0.0
   *
   */
   function mega_tour_render_cta_section( $content_details = array() ) {
        $options = mega_tour_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="call-to-action" class="relative page-section" style="background-image: url(<?php echo $options['cta_background_image']; ?>);">
                <div class="overlay"></div>
                <div class="wrapper">
                    <header class="entry-header">
                        <h2 class="entry-title"><?php echo esc_html($content_details['title']); ?></h2>
                    </header>

                    <div class="entry-content">
                        <p><?php echo wp_kses_post($content_details['excerpt']); ?></p>
                    </div><!-- .entry-content -->
                    
                </div>
            </div><!-- #call-to-action -->  
    <?php }
endif;