<?php
/**
 * Featured section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage Mega Tour
 * @since Mega Tour 1.0.0
 */
if ( ! function_exists( 'mega_tour_add_featured_section' ) ) :
    /**
    * Add featured section
    *
    *@since Mega Tour 1.0.0
    */
    function mega_tour_add_featured_section() {
    	
        // Check if Featured is enabled on frontpage
        $featured_enable = apply_filters( 'mega_tour_section_status', true, 'featured_section_enable' );

        if ( true !== $featured_enable ) {
            return false;
        }
       
        if ( class_exists( 'WP_Travel' )) {
            mega_tour_render_featured_section( );
        }
       
    }
endif;

if ( ! function_exists( 'mega_tour_render_featured_section' ) ) :
  /**
   * Start Featured section
   *
   * @return string Featured content
   * @since Mega Tour 1.0.0
   *
   */
   function mega_tour_render_featured_section( $content_details = array() ) {
        $options = mega_tour_get_theme_options();
        if ( $options['featured_content_type'] == 'category' ) {
            $cat_id = $options['featured_content_category'];
            $tax = 'category';
        }elseif ( $options['featured_content_type'] == 'trip-types' ){
            $cat_id = $options['featured_content_trip_types'];
            $tax  = 'itinerary_types';
        }
        ?>
        <div id="featured-packages" class="relative page-section">
            <div class="wrapper">
                <div class="section-header-wrapper clear">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['featured_title'] ) ; ?></h2>
                    </div><!-- .section-header -->
                </div><!-- .section-header-wrapper -->
                <?php if ( !empty( $cat_id ) ): ?>
                    <div class="featured-package-slider" data-slick='{"slidesToShow": 4, "slidesToScroll": 1, "infinite": false, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
                        <?php 
                        foreach ( $cat_id as $id ) {
                            $posts_array = get_posts(
                                array(
                                    'posts_per_page' => -1,
                                    'post_type' => array( 'post', 'itineraries' ),
                                    'tax_query' => array(
                                        array(
                                            'taxonomy' => $tax,
                                            'field' => 'term_id',
                                            'terms' => $id,
                                            )
                                        )
                                    )
                                );

                            $image = get_the_post_thumbnail_url( $posts_array[0]->ID );
                            ?>        
                    <article>
                        <div class="featured-image" style="background-image: url(<?php echo esc_url($image) ; ?>);">
                            <div class="overlay"></div>
                            <a href="<?php echo esc_url( get_category_link( $id ) ) ; ?>" class="btn"><?php esc_html_e('Explore More', 'mega-tour') ; ?></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <?php if ( $options['featured_content_type'] == 'trip-types' ):
                                $average_rating = 0;
                                foreach ( $posts_array as $post ) {
                                    $average_rating = $average_rating + wp_travel_get_average_rating( $post->ID );
                                 } 
                                 $average_rating = $average_rating/count($posts_array);
                            ?>
                               <div class="wp-travel-average-review"
                                title="<?php printf( esc_attr__( 'Rated %s out of 5', 'mega-tour' ), $average_rating ); ?>">
                                    <span style="width:<?php echo esc_attr( ( $average_rating / 5 ) * 100 ); ?>%">
                                        <strong itemprop="ratingValue"
                                            class="rating"><?php echo esc_html( $average_rating ); ?></strong>
                                        <?php printf( esc_html__( 'out of %1$s5%2$s', 'mega-tour' ), '<span itemprop="bestRating">', '</span>' ); ?>
                                    </span>
                                </div>
                            <?php endif ?>
                            

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( get_category_link( $id ) ) ; ?>"><?php echo ucfirst(esc_html( get_term_by( 'id', $id, $tax  )->name ) )  ;  ?></a></h2>
                                <p>
                                <?php echo count( $posts_array ) ; ?> 
                                 <?php 
                                    if ( $options['featured_content_type'] == 'category' ) {
                                        esc_html_e('Post Avialable', 'mega-tour');
                                    } if ( $options['featured_content_type'] == 'trip-types' ) {
                                        esc_html_e('Trip Avialable', 'mega-tour');
                                    }
                                 ?>
                                    
                                </p>
                            </header>
                        </div><!-- .entry-container -->
                    </article>
                    <?php  }
                    ?>
                </div><!-- .featured-package-slider -->
                <?php endif ; ?>
            </div><!-- .wrapper -->            
        </div><!-- #featured-packages -->
                
    <?php }
endif;